#ifndef _SET100B_H_
#define _SET100B_H_

inline write_cmos_sensor(UCHAR SubAddress,     // Register address
                  UCHAR Value)           // Register value
{
       SCCB_START();
       SCCB_Delay();
	   sccb_send_byte(0x66);
       SCCB_Delay();
	   sccb_send_byte(SubAddress);
       SCCB_Delay();
	   sccb_send_byte(Value);
       SCCB_Delay();
	   SCCB_STOP();
       return 0;
}

inline UCHAR read_cmos_sensor(UCHAR addr)
{
	UCHAR get_byte=0;
	get_byte=sccb_read(0x66,addr);
	return get_byte;
}	/* read_cmos_sensor() */

/*************************************************************************
* FUNCTION
*   SIV100B_Write_Sensor_Initial_Setting
*
* DESCRIPTION
*   This function initialize the registers of CMOS sensor.
*
* PARAMETERS
*   None
*
* RETURNS
*   None
*
* GLOBALS AFFECTED
*
*************************************************************************/
inline void SIV100B_Write_Sensor_Initial_Setting(void)
{
    write_cmos_sensor(0x04, 0x00);  // setup clock divider and HV-mirror
    write_cmos_sensor(0x05, 0x07);  // setup VGA output mode

    // Vendor recommended value ### Don't change ###
    write_cmos_sensor(0x11, 0x04);
    write_cmos_sensor(0x12, 0x0A);
    write_cmos_sensor(0x13, 0x1F);
    write_cmos_sensor(0x16, 0x89);
    write_cmos_sensor(0x1B, 0x90);
    write_cmos_sensor(0x1F, 0x52);

    /* SIV100B  60Hz - 30.00FPS(120/8) 24MHz */
    write_cmos_sensor(0x20, 0x00);
    write_cmos_sensor(0x21, 0x0C);
    write_cmos_sensor(0x22, 0x72);
    write_cmos_sensor(0x34, 0x7B);

    /* SIV100B  50Hz - 25.00FPS(100/4) 24MHz */
    write_cmos_sensor(0x23, 0x00);
    write_cmos_sensor(0x24, 0x73);
    write_cmos_sensor(0x25, 0x17);
    write_cmos_sensor(0x35, 0x83);

    write_cmos_sensor(0x33, 0x10);

    /* AE */
    write_cmos_sensor(0x40, 0x80);
    write_cmos_sensor(0x41, 0x8A);
    write_cmos_sensor(0x42, 0x7F);
    write_cmos_sensor(0x43, 0xC0);
    write_cmos_sensor(0x44, 0x40);
    write_cmos_sensor(0x45, 0x28);
    write_cmos_sensor(0x46, 0x08);
    write_cmos_sensor(0x47, 0x15);
    write_cmos_sensor(0x48, 0x1E);
    write_cmos_sensor(0x49, 0x13);
    write_cmos_sensor(0x4A, 0x63);
    write_cmos_sensor(0x4B, 0xC4);
    write_cmos_sensor(0x4C, 0x3C);
    write_cmos_sensor(0x4E, 0x17);
    write_cmos_sensor(0x4F, 0x8A);
    write_cmos_sensor(0x50, 0x94);

    write_cmos_sensor(0x5A, 0x00);

    /* Auto White Balance  0105 */
    write_cmos_sensor(0x60, 0xC8);
    write_cmos_sensor(0x61, 0x88);
    write_cmos_sensor(0x62, 0x01);
    write_cmos_sensor(0x63, 0x80);
    write_cmos_sensor(0x64, 0x80);
    write_cmos_sensor(0x65, 0xD0);
    write_cmos_sensor(0x66, 0x8C);
    write_cmos_sensor(0x67, 0xC8);
    write_cmos_sensor(0x68, 0x8B);
    write_cmos_sensor(0x69, 0x8A);
    write_cmos_sensor(0x6A, 0x73);
    write_cmos_sensor(0x6B, 0x95);
    write_cmos_sensor(0x6C, 0x70);
    write_cmos_sensor(0x6D, 0x88);
    write_cmos_sensor(0x6E, 0x77);
    write_cmos_sensor(0x6F, 0x46);
    write_cmos_sensor(0x70, 0xEA);
    write_cmos_sensor(0x71, 0x60);
    write_cmos_sensor(0x72, 0x05);
    write_cmos_sensor(0x73, 0x02);
    write_cmos_sensor(0x74, 0x0C);
    write_cmos_sensor(0x75, 0x0F);
    write_cmos_sensor(0x76, 0x20);
    write_cmos_sensor(0x77, 0xB7);
    write_cmos_sensor(0x78, 0x97);

    /* IDP */
    write_cmos_sensor(0x80, 0xAF);
    write_cmos_sensor(0x81, 0x0D); //Select Sensor's PCLK Polarity
    write_cmos_sensor(0x82, 0x1D); //Y,Cb,Cr Order Sequence   
    write_cmos_sensor(0x83, 0x00);
    write_cmos_sensor(0x86, 0xA1);
    write_cmos_sensor(0x87, 0x04);
    write_cmos_sensor(0x88, 0x24);//DPC Start Gain
    write_cmos_sensor(0x89, 0x0F);

    write_cmos_sensor(0x92, 0x44);
    write_cmos_sensor(0x93, 0x10);
    write_cmos_sensor(0x94, 0x20);
    write_cmos_sensor(0x95, 0x40);
    write_cmos_sensor(0x96, 0x10);
    write_cmos_sensor(0x97, 0x20);
    write_cmos_sensor(0x98, 0x30);
    write_cmos_sensor(0x99, 0x29);
    write_cmos_sensor(0x9A, 0x50);

    /* Shading  0106 */
    write_cmos_sensor(0xA4, 0xFF);
    write_cmos_sensor(0xA5, 0xFF);
    write_cmos_sensor(0xA6, 0xFF);
    write_cmos_sensor(0xA7, 0xED);
    write_cmos_sensor(0xA8, 0xCB);
    write_cmos_sensor(0xA9, 0x55);
    write_cmos_sensor(0xAA, 0x55);
    write_cmos_sensor(0xAB, 0x55);
    write_cmos_sensor(0xAC, 0x55);
    write_cmos_sensor(0xAE, 0x55);
    write_cmos_sensor(0xAD, 0x55);
    write_cmos_sensor(0xAF, 0x98);
    write_cmos_sensor(0xB0, 0x90);

    /* Gamma  0126 */
    write_cmos_sensor(0xB1, 0x00);
    write_cmos_sensor(0xB2, 0x08);
    write_cmos_sensor(0xB3, 0x10);
    write_cmos_sensor(0xB4, 0x23);
    write_cmos_sensor(0xB5, 0x45);
    write_cmos_sensor(0xB6, 0x62);
    write_cmos_sensor(0xB7, 0x78);
    write_cmos_sensor(0xB8, 0x8A);
    write_cmos_sensor(0xB9, 0x9B);
    write_cmos_sensor(0xBA, 0xAA);
    write_cmos_sensor(0xBB, 0xB8);
    write_cmos_sensor(0xBC, 0xCE);
    write_cmos_sensor(0xBD, 0xE2);
    write_cmos_sensor(0xBE, 0xF3);
    write_cmos_sensor(0xBF, 0xFB);
    write_cmos_sensor(0xC0, 0xFF);

    /* Color Matrix */
    write_cmos_sensor(0xC1, 0x3D);
    write_cmos_sensor(0xC2, 0xC6);
    write_cmos_sensor(0xC3, 0xFD);
    write_cmos_sensor(0xC4, 0x10);
    write_cmos_sensor(0xC5, 0x21);
    write_cmos_sensor(0xC6, 0x10);
    write_cmos_sensor(0xC7, 0xF3);
    write_cmos_sensor(0xC8, 0xBD);
    write_cmos_sensor(0xC9, 0x50);

    /* Edge */
    write_cmos_sensor(0xCA, 0x90);
    write_cmos_sensor(0xCB, 0x20);
    write_cmos_sensor(0xCC, 0x30);
    write_cmos_sensor(0xCD, 0x06);
    write_cmos_sensor(0xCE, 0x06);
    write_cmos_sensor(0xCF, 0x10);
    write_cmos_sensor(0xD0, 0x20);
    write_cmos_sensor(0xD1, 0x2A);
    write_cmos_sensor(0xD2, 0x86);
    write_cmos_sensor(0xD3, 0x00);

    /* Contrast */
    write_cmos_sensor(0xD4, 0x10);
    write_cmos_sensor(0xD5, 0x12);
    write_cmos_sensor(0xD6, 0x12);
    write_cmos_sensor(0xD7, 0x00);
    write_cmos_sensor(0xD8, 0x00);
    write_cmos_sensor(0xD9, 0x00);
    write_cmos_sensor(0xDA, 0x00);
    write_cmos_sensor(0xDB, 0xFF);
    write_cmos_sensor(0xDC, 0x00);
    write_cmos_sensor(0xDD, 0xFF);
    write_cmos_sensor(0xDE, 0x00);
    write_cmos_sensor(0xDF, 0xFF);
    write_cmos_sensor(0xE0, 0x00);	

    /* Saturation */
    write_cmos_sensor(0xE1, 0x24);
    write_cmos_sensor(0xE2, 0x58);
    
   /* Windowing */    
    write_cmos_sensor(0xF0, 0x24);
    write_cmos_sensor(0xF1, 0x00);    
    write_cmos_sensor(0xF2, 0x80);
    write_cmos_sensor(0xF3, 0x00);    	
    write_cmos_sensor(0xF4, 0xE0); 
    
    write_cmos_sensor(0x03, 0xC5);    

    write_cmos_sensor(0x7A, 0x90);
    write_cmos_sensor(0x7B, 0xB0);
    write_cmos_sensor(0x7C, 0x80);
}   /* SIV100B_Write_Sensor_Initial_Setting */
#endif
